{% extends 'madc/base.html' %}
{% load i18n %}
{% load humanize %}
{% load bootstrap %}

{% block page_title %}
    {{ title }} ⋗ {% translate "Doctrine Checker" %}
{% endblock %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block view_block %}
<div class="card-body bg-primary rounded-top d-flex align-items-center">
    <h3 class="me-3">{% translate "Doctrine Checker" %}</h3>

</div>
<div class="card-body rounded-bottom">
    <div class="mb-3">
        <label for="category-filter" class="form-label">{% translate "Filter by Category" %}</label>
        <select id="category-filter" class="form-select" style="width: 200px;">
            <option value="">{% translate "All Categories" %}</option>
        </select>
    </div>
    {% include 'madc/partials/table/skill-checker.html' %}
</div>
{% endblock %}

{% block extra_javascript %}
    {% include 'bundles/datatables-js-bs5.html' %}
    {% include 'bundles/clipboard-js.html' %}
    {% include 'madc/bundles/settings-bundles.html' %}
    {% include 'madc/bundles/skill-checker-bundles.html' %}

    {% include 'madc/partials/modals/modal.html' with name="ViewMissing" %}

    <script type="application/javascript">
        setupModal('#modalViewMissingContainer', 'ajax_missing', '#modalViewMissingContent', '#modalViewMissingLoader');
    </script>
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
